Kanta.Backend.GettextFallback (kanta v0.5.1)
Provides a fallback mechanism to Gettext's PO files translation system.
This module creates a nested Gettext backend that is used when database translations are not found. It allows Kanta to gracefully fall back to standard PO file translations when a specific translation is not available in the database.