Kanta.PoFiles.Services.StaleDetection.Result (kanta v0.5.1)

Result struct for stale translation detection.

Contains information about stale messages and their fuzzy matches.

Terminology

  • fuzzy_matches_map: Map of stale message IDs to their FuzzyMatch structs
  • mergeable_count: User-facing count of messages that can be automatically merged

Summary

Types

t()

@type t() :: %Kanta.PoFiles.Services.StaleDetection.Result{
  fuzzy_matches_map: %{
    required(integer()) => Kanta.PoFiles.Services.StaleDetection.FuzzyMatch.t()
  },
  mergeable_count: integer(),
  stale_count: integer(),
  stale_message_ids: MapSet.t(integer())
}

Functions

new(stale_message_ids, fuzzy_matches_map)

@spec new(
  stale_message_ids :: MapSet.t(integer()),
  fuzzy_matches_map :: %{
    required(integer()) => Kanta.PoFiles.Services.StaleDetection.FuzzyMatch.t()
  }
) :: t()