Kanta.PoFiles.Services.StaleDetection.FuzzyMatch (kanta v0.5.1)
Represents a fuzzy match between a stale message and an active message.
This struct contains information about a potential replacement for a stale message, including the similarity score and identifiers for both messages.
Summary
Functions
Creates a new FuzzyMatch struct.
Types
Functions
@spec new( stale_message_id :: integer(), matched_message_id :: integer(), matched_msgid :: String.t(), similarity_score :: float() ) :: t()
Creates a new FuzzyMatch struct.
Parameters
stale_message_id- ID of the stale messagematched_message_id- ID of the active message that matchesmatched_msgid- The msgid string of the matched messagesimilarity_score- Jaro distance score (0.0-1.0)