Kanta.PoFiles.Services.StaleDetection.Result (kanta v0.5.1)
Result struct for stale translation detection.
Contains information about stale messages and their fuzzy matches.
Terminology
- fuzzy_matches_map: Map of stale message IDs to their FuzzyMatch structs
- mergeable_count: User-facing count of messages that can be automatically merged
Summary
Types
Functions
@spec new( stale_message_ids :: MapSet.t(integer()), fuzzy_matches_map :: %{ required(integer()) => Kanta.PoFiles.Services.StaleDetection.FuzzyMatch.t() } ) :: t()